#include <stdlib.h>
#include <glib.h>
#include <gmodule.h>
#include <gtk/gtkmain.h>
#include <gtk/gtksignal.h>
#include <multisync.h>
#include <dirent.h>
#include "ldap_plugin.h"
#include "gui.h"
#include "interface.h"
#include "support.h"
#include <iconv.h>

GtkWidget* ldapoptions = NULL;

ldap_connection *ldapconn = NULL;

GtkWidget* open_option_window(sync_pair *pair, connection_type type)
{
  char *str;

  if(!ldapoptions)
  {
    ldapconn = g_malloc0(sizeof(ldap_connection));

    ldapconn->sync_pair = pair;
    ldapconn->conntype = type;

    ldap_load_state(ldapconn);

    ldapoptions = create_ldapoptions();

    gtk_widget_show (ldapoptions);


    if(ldapconn->servername == NULL)
      ldapconn->servername = g_strdup("");

    gtk_entry_set_text(GTK_ENTRY(lookup_widget(ldapoptions, "serverentry")), 
		       ldapconn->servername);


    if(ldapconn->serverport != 0)
      str = g_strdup_printf("%d", ldapconn->serverport);
    else
      str = g_strdup("");

    gtk_entry_set_text(GTK_ENTRY(lookup_widget(ldapoptions, "portentry")), 
		       str);
    g_free(str);

    
    if(ldapconn->binddn == NULL)
      ldapconn->binddn = g_strdup("");

    gtk_entry_set_text(GTK_ENTRY(lookup_widget(ldapoptions, "binddnentry")), 
		       ldapconn->binddn);

    if(ldapconn->pwd == NULL)
      ldapconn->pwd = g_strdup("");

    gtk_entry_set_text(GTK_ENTRY(lookup_widget(ldapoptions, "passwordentry")), 
		       ldapconn->pwd);

    if(ldapconn->searchbase == NULL)
      ldapconn->searchbase = g_strdup("");

    gtk_entry_set_text(GTK_ENTRY(lookup_widget(ldapoptions, "searchentry")), 
		       ldapconn->searchbase);

    if(ldapconn->filter == NULL)
      ldapconn->filter = g_strdup("");

    gtk_entry_set_text(GTK_ENTRY(lookup_widget(ldapoptions, "filterentry")), 
		       ldapconn->filter);
  }

  return(ldapoptions);
}

void ldap_window_closed(void) 
{
  sync_plugin_window_closed();

  if(ldapconn)
    g_free(ldapconn);

  ldapoptions = NULL;
  ldapconn = NULL;
}


void ldapoptions_cancel(void) 
{
  if(ldapconn)
    g_free(ldapconn);

  gtk_widget_destroy(ldapoptions);
  ldap_window_closed();
}

void ldapoptions_ok(void)
{
  char *str;

  if(ldapconn->servername)
    g_free(ldapconn->servername);

  ldapconn->servername = (char*)gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(ldapoptions, "serverentry")), 0, -1);

  str = (char*)gtk_entry_get_text(GTK_ENTRY(lookup_widget(ldapoptions, "binddnentry")));
  sscanf(str, "%d", ldapconn->serverport);

  if(ldapconn->binddn)
    g_free(ldapconn->binddn);

  ldapconn->binddn = (char*)gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(ldapoptions, "binddnentry")), 0, -1);

  if(ldapconn->pwd)
    g_free(ldapconn->pwd);

  ldapconn->pwd = (char*)gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(ldapoptions, "passwordentry")), 0, -1);

  if(ldapconn->searchbase)
    g_free(ldapconn->searchbase);

  ldapconn->searchbase = (char*)gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(ldapoptions, "searchentry")), 0, -1);

  if(ldapconn->filter)
    g_free(ldapconn->filter);

  ldapconn->filter = (char*)gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(ldapoptions, "filterentry")), 0, -1);


  ldap_save_state(ldapconn);

  if(ldapconn)
    g_free(ldapconn);

  gtk_widget_destroy(ldapoptions);
  ldap_window_closed();
}
